# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_without maven
%bcond_with gcj_support
%bcond_without repolib

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free
%define namedver %{version}

%define version_full %{namedver}

%define repodir %{_javadir}/repository.jboss.com/org/codehaus/jettison/%{version_full}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

Name:           jettison
Version:        1.2
Release:        4%{?dist}
Epoch:          0
Summary:        JSON StAX Implementation
License:        ASL 2.0
Group:          Text Processing/Markup/XML
URL:            http://jettison.codehaus.org
# svn export http://svn.codehaus.org/jettison/tags/jettison-1.2/ jettison-1.2
# Exported revision 95.
# tar cjf jettison-1.2.tar.bz2 jettison-1.2
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml
Source3:        %{name}-build.xml
Source4:        %{name}-component-info.xml
Patch0:         %{name}-BadgerFishXMLStreamWriterTest.patch
Requires(post): jpackage-utils >= 0:1.7.2
Requires(postun): jpackage-utils >= 0:1.7.2
Requires:       jpackage-utils >= 0:1.7.2
Requires:       stax_1_0_api
BuildRequires:  jpackage-utils >= 0:1.7.2
BuildRequires:  junit >= 0:3.8.2
BuildRequires:  wstx >= 0:3.2.2
%if %with maven
BuildRequires:  maven2 >= 2.0.4-10jpp
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-release
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-surefire
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  felix-maven2
%else
BuildRequires:  ant
%endif
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRequires:  stax_1_0_api
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Jettison is a collection of StAX parsers and writers which 
read and write JSON. This allows nearly transparent 
enablement of JSON based web services in services 
frameworks like CXF.

There are currently two included conventions for mapping 
JSON to XML. The first, is BadgerFish which implements the 
full XML infoset in JSON using various techniques. 
The second, is called the "mapped" convention. It allows 
you to manually map XML namespaces to JSON element prefixes.
Jettison was developed for usage in XFire and CXF to enable 
JSON based services.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:     Artifacts to be uploaded to a repository library
Group:       Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q
cp -p %{SOURCE1} settings.xml
cp -p %{SOURCE3} build.xml
%patch0 -p0

%if %with maven
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
sed -i -e "s|<url>__ECLIPSEDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/eclipse/plugins</url>|g" settings.xml

mkdir external_repo
ln -s %{_javadir} external_repo/JPP
%endif

%build
%if %with maven
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL
%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        -Dmaven2.jpp.mode=true \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        install javadoc:javadoc
%else
export CLASSPATH=$(build-classpath stax_1_0_api):target/classes:target/test-classes
export OPT_JAR_LIST="junit ant/ant-junit"
%{ant} -Dbuild.sysclasspath=only jar javadoc
%endif

pushd src/main/java
%{jar} cf ../../../target/%{name}-src-%{namedver}.jar org
pushd ../resources
%{jar} uf ../../../target/%{name}-src-%{namedver}.jar META-INF
popd
popd

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}%{_javadir}
%if %with maven
cp -p target/jettison-%{namedver}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%else
cp -p target/jettison.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%endif
cp -p target/jettison-src-%{namedver}.jar %{buildroot}%{_javadir}/%{name}-src-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do ln -s ${jar} ${jar/-%{version}/}; done)
%add_to_maven_depmap org.codehaus.jettison %{name} %{namedver} JPP %{name}


# poms
mkdir -p %{buildroot}%{_datadir}/maven2/poms
cp -p pom.xml %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}/
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%if %with repolib
mkdir -p %{buildroot}%{repodir}
mkdir -p %{buildroot}%{repodirlib}
mkdir -p %{buildroot}%{repodirsrc}
cp -p %{SOURCE0} %{buildroot}%{repodirsrc}
cp -p %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/%{name}.jar
cp -p target/%{name}-src-%{namedver}.jar %{buildroot}%{repodirlib}/%{name}-src.jar
cp -p %{SOURCE4} %{buildroot}%{repodir}/component-info.xml
sed -i 's/@VERSION@/%{version_full}-brew/g' %{buildroot}%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%endif

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf %{buildroot}

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap 
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-src-%{version}.jar
%{_javadir}/%{name}-src.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-*%{version}.jar.*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}
%{_javadir}/repository.jboss.com
%endif

%changelog
* Mon May 02 2011 Weinan Li <weli@redhat.com> - 0:1.2-4
- Add depmap entry for stax-api

* Mon May 2 2011 Weinan Li <weli@redhat.com> - 0:1.2-3
- Upgrade to 1.2

* Thu Aug 05 2010 David Walluck <dwalluck@redhat.com> 0:1.1-1.4
- fix name of installed pom
- add manually created src jar to package
- build with maven2
- remove spurious dependency on jakarta-slide-webdavclient
- remove spurious dependency on jetty5
- remove spurious dependency on servletapi5
- remove spurious dependency on xml-commons-jaxp-1.3-apis
- remove spurious dependency on xstream

* Fri May 07 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.1-1.3.1
- rebuilt

* Wed Apr 07 2010 Hui Wang <huwang@redhat.com> 0:1.1-1.3
- Rebuild

* Thu Feb 25 2010 David Walluck <dwalluck@redhat.com> 0:1.1-1.2
- bump release

* Thu Feb 25 2010 David Walluck <dwalluck@redhat.com> 0:1.1-1.1
- use stax_1_0_api
- fix gcj_support and repolib options

* Thu Jul 16 2009 Yong Yang <yyang@redhat.com> 0:1.1-1
- Upgrade to 1.1
- Add "BuildRequires: wstx" and add jpp-depmap for wstx-asl

* Thu Feb 05 2009 Martha Benitez <mbenitez@redhat.com>
- Change export stax_1_0_api to bea-stax-api
- Comment out jetty5
- Add BR xstream

* Mon Jan 12 2009 David Walluck <dwalluck@redhat.com> 0:1.0.1-3
- change repolib location for AS5

* Thu Sep 25 2008 David Walluck <dwalluck@redhat.com> 0:1.0.1-2
- remove get-deps target from build.xml

* Thu Sep 25 2008 David Walluck <dwalluck@redhat.com> 0:1.0.1-1
- 1.0.1

* Mon Aug 11 2008 David Walluck <dwalluck@redhat.com> 0:1.0-0.rc2.1
- 1.0-RC2

* Wed Jun 06 2007 Ralph Apel <r.apel at r-apel.de> 0:1.0-0.rc1.1jpp
- Initial build
